package org.apache.turbine.services.intake.model;

/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and 
 *    "Apache Turbine" must not be used to endorse or promote products 
 *    derived from this software without prior written permission. For 
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache Turbine", nor may "Apache" appear in their name, without 
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

// JDK classes
import java.util.*;
import java.beans.*;

import org.apache.regexp.RE;
import org.apache.regexp.RESyntaxException;

// Turbine classes
import org.apache.turbine.om.*;
import org.apache.turbine.util.ObjectUtils;
import org.apache.turbine.util.StringUtils;
import org.apache.turbine.util.ParameterParser;
import org.apache.turbine.util.Log;
import org.apache.turbine.util.TurbineException;
import org.apache.turbine.services.intake.xmlmodel.*;
import org.apache.turbine.services.intake.*;


/**  */
public class IntegerField extends Field
{
    protected final int onError;

    protected final int minValue;
    protected final String minValueMessage;
    protected final boolean minValueForce;
    protected final int maxValue;
    protected final String maxValueMessage;
    protected final boolean maxValueForce;

    public IntegerField(XmlField field, Group group)
        throws Exception
    {
        super(field, group);
        onError = Integer.parseInt(field.getOnError());
        
        int tmpMinValue = Integer.MIN_VALUE;
        String tmpMinValueMessage = null;
        boolean tmpMinValueForce = false;
        int tmpMaxValue = Integer.MAX_VALUE;
        String tmpMaxValueMessage = null;
        boolean tmpMaxValueForce = false;
        for (int i=0; i<field.getRules().size(); i++) 
        {
            Rule rule = (Rule)field.getRules().get(i);

            if ( rule.getMinValue() != null )
            {
                tmpMinValue = Integer.parseInt(rule.getMinValue());
                tmpMinValueMessage = rule.getMessage();
                tmpMinValueForce = "force".equals(rule.getAction());
            }

            if ( rule.getMaxValue() != null )
            {
                tmpMaxValue = Integer.parseInt(rule.getMaxValue());
                tmpMaxValueMessage = rule.getMessage();
                tmpMaxValueForce = "force".equals(rule.getAction());
            }
        }  
        minValue = tmpMinValue;
        minValueMessage  = tmpMinValueMessage;
        minValueForce  = tmpMinValueForce;
        maxValue = tmpMaxValue;
        maxValueMessage  = tmpMaxValueMessage;
        maxValueForce  = tmpMaxValueForce;
    }
    
    /**
     * Compares request data with constraints and sets the valid flag.
     */
    protected void doValidate(ParameterParser pp)
    {
        if ( isMultiValued  ) 
        {
            String[] ss = pp.getStrings(getKey());
            int[] ival = new int[ss.length];
            for (int i=0; i<ss.length; i++) 
            {
                ival[i] = checkString(ss[i]);
            }
            iv.setTestValue(ival);
        }
        else 
        {
            iv.setTestValue(new Integer(checkString(pp.getString(getKey()))));
        }
    }

    /**
     * Compares request data with constraints and sets the valid flag.
     */
    private int checkString(String val)
    {
        int ival = onError;
        try
        {
            ival = Integer.parseInt(val);
        }
        catch (Exception e)
        {
            valid_flag = false;
            ival = onError;
        }

        boolean b;
        if ( maxLength > 0 )
        {
            b = val.length() > maxLength; 
            if ( maxLengthForce  && b )
            {
                val = val.substring(0, maxLength);
                try
                {
                    ival = Integer.parseInt(val);
                }
                catch (NumberFormatException nfe)
                {
                    valid_flag = false;
                    ival = onError;
                }
            }
            else 
            {
                valid_flag &= !b;
            }
            if (maxLengthMessage  != null && b)
            {
                message = maxLengthMessage;
            }
        }

        if ( minValue != Integer.MIN_VALUE )
        {
            b = ival < minValue;
            if ( minValueForce  && b )
            {
                ival = minValue;
            }
            else 
            {
                valid_flag &= !b;
            }
            if (minValueForce  && b)
            {
                message = minValueMessage;
            } 
        }

        if ( maxValue != Integer.MAX_VALUE  )
        {
            b = ival > maxValue;
            if ( maxValueForce  && b )
            {
                ival = maxValue;
            }
            else 
            {
                valid_flag &= !b;
            }
            if (maxValueForce  && b)
            {
                message = maxValueMessage;
            } 
        }
        return ival;
    }
}



















